@@ -50,42 +50,40 @@ public:
 
 public slots:
 	void keyPress(unsigned int keycode);
-
-	void toggleCaps();
 	void toggleNumlock();
-
-	void toggleShift();
-
-	void queryModState();
-	void showDock();
-	
-	void quitClicked();
-	void chooseFont();
+	void toggleShiftCapsAltGr(unsigned int keycode);
 	void toggleNumericPad();
 	void toggleFontAutoRes();
+	void toggleLock();
+	void queryModState();
+	void showDock();
+	void chooseFont();
+	void chooseBackgroundColor();
+	void chooseKeysColor();
 	void restorePosition();
 	void showConfigMenu();
-// 	void shutDown();
  	void saveState();
+	void quitClicked();
 
 protected:
 	void resizeEvent(TQResizeEvent *e);
-	void hideEvent ( TQHideEvent *e );
-
+	void hideEvent(TQHideEvent *e);
+	void setLockState(bool lock);
 
 private:
 	void updateFont();
+	void updateNumlock();
+	void updateShiftCapsAltGr();
 
 	bool nresize;
 
 	bool keyState(int iKey);
 	void keyPress(int keycode);
-	void setupText(VButton &v);
 
 
 	VButton *caps;
-	VButton *lshft;
-	VButton *rshft;
+	VButton *lshift;
+	VButton *rshift;
 
 	VButton *lctrl;
 	VButton *rctrl;
@@ -93,7 +91,8 @@ private:
 	VButton *lalt;
 	VButton *ralt;
 
-	VButton *win;
+	VButton *lwin;
+	VButton *rwin;
 	VButton *mnu;
 
 	VButton *numl;
@@ -111,15 +110,13 @@ private:
 	TQValueList<VButton *> other_keys;
 	TQValueList<NumpadVButton *> numl_keys;
 
-	void send_key(unsigned int keycode, bool press, bool release);
+	void send_key(unsigned int keycode);
 	 
 	Display *display;	
 	KbdTray *tray;
 	KbdDock *dock;
 
 	bool stand_alone;
-	long keysym2ucs(KeySym keysym);
-
 	bool extent_visible;
 	VButton *quit;
 	VButton *popup_menu;
@@ -128,7 +125,7 @@ private:
 	double sdxb;
 	int mnu_dock;
 	int mnu_autores;
-
+	int mnu_lock;
 };
 
 
